@@ -1,7 +1,7 @@
 utils::globalVariables(c('.', 'Var1', 'Var2', 'Yhat', 'beta1', 'beta1_se', 'csr', 'data', 'ecdf', 'fundiff',
                          'grid', 'lower', 'predict', 'r', 'setNames', 'sumfuns', 'theo', 'upper', 'value', 'x',
                          'y', 'hr', 'sumfun', 'Keep', 'fit', 'fit+se', 'fit-se', 'number_computable', 'patient_id',
-                         'score'))
+                         'score', 'marks'))
 juliawrobel_email = "julia.wrobel@emory.edu"
 alexsoupir_email = "alex.soupir@moffitt.org"
 thaovu_email = "thao.3.vu@cuanschutz.edu"
